onavg-ind
---------

Ongoing development of extension package to the `"Open Neuro Average" template, or "onavg" template <https://feilong.github.io/tpl-onavg/index.html>`_ 
for individual surface refinement and registration.

Currently, this only functions as a clunky registration tool to go from individual HCP-Native space to onavg space (but not backwards, lol)

Active development - everything subject to change.

Install with ``pip install onavg_ind``